#
# spec file for package spotify-qt
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           spotify-qt
Version:        4.0.0
Release:        2.1
Summary:        Lightweight Spotify client using Qt
License:        GPL-3.0-only
URL:            https://github.com/kraxarn/spotify-qt
Source:         https://github.com/kraxarn/spotify-qt/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Group:          Productivity/Multimedia/Sound/Players
%if 0%{?suse_version} < 1600
BuildRequires: gcc12
BuildRequires: gcc12-c++
%else
BuildRequires: gcc
BuildRequires: gcc-c++
%endif
BuildRequires:  libsecret
BuildRequires:  make
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6DBus)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6Svg)
BuildRequires:  cmake(Qt6Widgets)
Suggests:       libsecret
%if 0%{?suse_version} >= 1600 && 0%{?is_opensuse}
Suggests:       librespot
%endif

%description
An unofficial Spotify client using Qt as a simpler, lighter alternative to the official client, inspired by spotify-tui. Much like spotify-tui, you need an actual Spotify client running, for example spotifyd, which can be configured from within the app. Also like other clients, controlling music playback requires Spotify Premium.

%prep
%setup -q

%build
%if 0%{?suse_version} < 1600
export CC=gcc-12
export CXX=g++-12
%endif
%cmake
%cmake_build

%install
%cmake_install

%check
%ctest

%files
%license license
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/
%{_datadir}/icons/hicolor/scalable/
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

%changelog
* Thu May 15 2025 ecsos <ecsos@opensuse.org>
- Fix build error under Leap 15.6
  As described in changelog spotify-qt now requires QT6.
* Tue Apr 29 2025 Tobias Schula <tobias@schula.org>
- Update to version 4.0.0
  Major Changes
  * Now defaults to Qt 6.
  * Deprecated Qt 5 support, to be removed in the next major release.
  * Now requires C++17 on all platforms, as required by Qt 6.
  * Development builds now use an incrementing "-dev" suffix instead of using the commit hash.
  * Now uses "x.y.z" versioning, in an attempt for more frequent updates.
  * Renamed the "master" branch to "develop" to clearer indicate it's in-development and unstable.
  Fixes
  * Fixed Qt 6.9 support (#284).
  Changes
  * Changed "localhost" during auth to "127.0.0.1" (#281).
  * Now requires CMake 3.16 or newer.
  * Now targets macOS 12, as required by Qt 6.
* Fri Dec 20 2024 Jens K. <karatekhd@opensuse.org>
- Add checks for SUSE Version
- Switch suggestion from spotifyd to librespot
* Sat Dec 14 2024 Jens K. <karatekhd@opensuse.org>
- Move to QT6
* Sat Dec 14 2024 Jens K. <karatekhd@opensuse.org>
- Update to version 3.12
  Fixes
  * Fixed show/hide for "Added" column not being properly saved (#219, #267).
  * Fixed some crashes related to starting Spotify client (#251, #252).
  * Fixed search not loading results properly (#268).
  * Fixed showing "0 tracks" in album context menu for non-cached albums until loaded.
  * Fixed showing empty invalid playlists in the list of playlists.
  * Fixed layout breaking on long status messages.
  * Fixed sometimes showing a failed status for successful actions.
  Changes
  * Track and artist can now be clicked in now playing preview (#253).
  * Added option to like albums from context menu (#255).
  * Improved performance when loading artist albums.
  * Added support for setting custom window and tray icon titles.
  * Reworked "New Releases" to fetch everything as albums.
  * Improved performance when loading album tracks.
  * Removed support for saving passwords, as it's no longer supported.
  * Removed optional keychain dependency.
  * Added support for new OAuth authentication.
  * Now requires librespot v0.5.0 or newer.
  * Removed deprecated "Audio features".
  * Improved performance when loading playlists.
  * Now shows "Open/Close" in tray icon when "Close to tray" is enabled.
  * Improved error messages from Spotify client.
  * No longer shows "Related" artists when not available.
* Mon Jan  1 2024 Jens K. <karatekhd@opensuse.org>
- Update to version 3.11
  Fixes
  * Fixed build on FreeBSD.
  * Fixed current track sometimes not showing as playing in tracks list.
  * Fixed progress slider performing double click actions with some styles.
  * Fixed HTML tags in playlists descriptions not displaying properly.
  * Fixed some systems not being able to open links or files properly.
  * Fixed "Added" sometimes showing negative values on just added tracks.
  Changes
  * Much improved performance when loading playlists.
  * Added support for track queue.
  * Added an option to ignore unavailable tracks in playlists.
  * Added support for librespot v0.5.0.
  * Added tooltips for links for artists.
  * Much improved performance with a lot of liked tracks.
  * Added support for passing custom arguments to Spotify client.
  * Added history.
  * Improved resizing with expanded album art.
  * Added an option for tabbed library and playlists.
  * The main toolbar can now be placed at the bottom of the window.
  * Settings can now be saved, even if an invalid Spotify client path is provided.
  * The shape of the album art can now be changed.
  * Improved performance with "Recent" playlist sorting.
  * Added new tooltips for tracks, albums, and playlists.
* Sat Mar 25 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 3.10
  Fixes
  * Fixed not being able to change volume on some styles.
  * Fixed crash when playing library items with many tracks.
  * Fixed MPRIS support on Qt 6.
  * Fixed side panel tabs not working on some styles.
  * Fixed not showing tool-tip for added date in albums.
  * Fixed using Fusion style when saving settings with default
    selected.
  * Fixed not displaying artist names with "&" properly.
  * Fixed flat buttons having a background with built-in dark theme
  * Fixed not refreshing some cached albums correctly.
  Changes
  * Added automatic re-authentication if token expired.
  * Improved error handling when setting client path.
  * Added support for saving passwords on more Linux systems.
  * Added column for track liked status.
  * Disallowed actions are now disabled.
  * Client volume is now remembered instead of always being 100%%
  * Added options for copying name of playlist/track/album.
  * Added support for librespot v0.5.0.
  * Added back lyrics.
  * Improved startup performance.
  * Replaced "Save password in keyring" option with "Remember me"
    in password entry.
  * Replaced "fixed width remaining time" with custom fixed-width
    system font.
* Thu Aug 11 2022 Jens K. <karatekhd@opensuse.org>
- Update to version 3.9
  - Fixes
  * Fixed not being able to move window under Wayland.
  * Fixed showing add and remove options for tracks in collaborative playlists.
  * Fixed some possible issues with selecting a device.
  * Fixed MPRIS support under KDE.
  * Fixed crash when opening links on some artists.
  - Changes
  * Much improved MPRIS support.
  * Added keyboard shortcuts.
  * Added support for playing tracks from outside the application.
  * Added support for selecting multiple tracks.
  * Added an option to use an expanded album cover.
  * Added an option to close application to the tray.
  * Improved detection of spotifyd config files.
  * Added an option to change device type.
  * Added message when queuing tracks.
  * Replaced custom font option with ability to select font from system.
  * Added an option to disable checking for updates on start.
* Tue Jan 18 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Clean up spec file a bit:
  + Drop empty post/postubn scriptlets
  + Remove not used requires on hicolor-icon-theme,
    shared-mime-info, and update-desktop-files.
  + Package license file.
  + Set license to GPL-3.0-only: there is no indication that
    GPL-3.0-or-later is valid.
* Mon Jan 17 2022 Jens K. <karatekhd@opensuse.org>
- Update to version 3.8:
  - Fixes
  * Fixed empty context menu when right-clicking empty spaces.
  * Fixed not updating playlist when deleting a track.
  * Fixed incorrect track order after deleting a track in a playlist.
  * Fixed paging not working with some lists.
  * Fixed not removing extra spacing when using system title bar.
  * Fixed issues with followed playlists by other users not updating properly.
  * Fixed issue when attempting to search for nothing.
  * Fixed issues resuming playback when last used device was no longer available.
  - Changes
  * Added an option to show desktop notification on track change.
  * Added support for repeating a single track.
  * Added support for podcasts.
  * New and improved volume slider.
  * Already opened artists are now re-used.
  * Added support for mirrored title bar buttons.
  * Added support for creating new playlists.
  * Added support for following, and unfollowing, playlists.
  * New status messages, replacing the status bar and desktop notifications.
  * Added a custom font for the custom dark theme.
  * Now continues playing tracks from search results.
  * Now shows more artists links, for example social media links.
  * Removed broken "PulseAudio volume control" setting.
  * Tracks in albums now show an added date for when the album released.
  * New categories in settings for logs and for troubleshooting.
* Sun Aug 15 2021 Jens K. <jens@karatek.net>
- Bump version to 3.7
* Mon May 17 2021 Jens K. <karatek@karatek.net>
- Add description.
* Mon May 17 2021 Jens K. <karatek@karatek.net>
- Stuff
* Mon May 17 2021 Jens K. <karatek@karatek.net>
- Initial Commit
